#!/bin/sh
export PATH='/usr/obj/hs-mtl-2.1.3.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: mtl
version: 2.1.3.1
id: mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269

license: BSD3
copyright:
maintainer: Edward Kmett <ekmett@gmail.com>
stability:
homepage: http://github.com/ekmett/mtl
package-url:
synopsis: Monad classes, using functional dependencies
description: Monad classes using functional dependencies, with instances
             for various monad transformers, inspired by the paper
             /Functional Programming with Overloading and Higher-Order Polymorphism/,
             by Mark P Jones, in /Advanced School of Functional Programming/, 1995
             (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
pkgpath: devel/hs-mtl
exposed: True
exposed-modules: Control.Monad.Cont Control.Monad.Cont.Class
                 Control.Monad.Error Control.Monad.Error.Class
                 Control.Monad.Identity Control.Monad.List Control.Monad.RWS
                 Control.Monad.RWS.Class Control.Monad.RWS.Lazy
                 Control.Monad.RWS.Strict Control.Monad.Reader
                 Control.Monad.Reader.Class Control.Monad.State
                 Control.Monad.State.Class Control.Monad.State.Lazy
                 Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
                 Control.Monad.Writer.Class Control.Monad.Writer.Lazy
                 Control.Monad.Writer.Strict
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/mtl-2.1.3.1
library-dirs: /usr/local/lib/ghc/mtl-2.1.3.1
hs-libraries: HSmtl-2.1.3.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         transformers-0.3.0.0-6458c21515cab7c1cf21e53141557a1c
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-mtl-2.1.3.1/html/mtl.haddock
haddock-html: /usr/local/share/doc/hs-mtl-2.1.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
